#include "selector.ih"

int Selector::checkSet(int *index, fd_set const &set)
{
    int &idx = *index;

    while (idx < d_max && !FD_ISSET(idx, &set))
        ++idx;

    return idx == d_max ? -1 : idx++;
}

